#
# spec file for package hibiscus
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _build 369
%define tag V_2_8_6_BUILD_%{_build}

Name:           hibiscus
Summary:        Java online banking client using the HBCI standard
License:        GPL-2.0-only AND LGPL-2.0-only AND Apache-2.0 AND CPL-1.0 AND Zlib AND MPL-1.0 AND EPL-1.0
Group:          Productivity/Office/Finance
Version:        2.8.6
Release:        11.3
Url:            https://www.willuhn.de/products/hibiscus/
Source:         https://github.com/willuhn/hibiscus/archive/%{tag}.tar.gz
Source2:        hibiscus-rpmlintrc
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  ant
BuildRequires:  desktop-file-utils
BuildRequires:  hicolor-icon-theme
BuildRequires:  jameica-devel >= 2.8.0
BuildRequires:  java-devel >= 1.6
BuildRequires:  jpackage-utils
BuildRequires:  xml-commons-apis
Requires:       jameica >= 2.8.0
BuildRequires:  swtchart = 0.10.0
Requires:       swtchart = 0.10.0
BuildRequires:  pcsc-towitoko-devel
Requires:       pcsc-towitoko-devel
BuildRequires:  obantoo = 2.1.12
Requires:       obantoo = 2.1.12
BuildRequires:  fdupes
# Don't offer libraries linked in here to other packages:
AutoReqProv:    off

%description
A free Java homebanking application that uses the HBCI4Java implementation
and runs as a plugin inside the Jameica framework. Support chipcards
key files and PIN/TAN including chipTAN and smsTAN for authentification.
Supported file formats include MT940, DTAUS, CSV, Moneyplex and PDF/HTML.

%prep
%setup -n %{name}-%{tag} -q

# Remove Windows and Mac libraries
rm -rf lib/hbci4java-card-*

# older version of the CTAPI driver from Kobil
# can't be build from source
# questionable redistribution rights
rm lib/libct.so

# required for reading older key files in SIZ-RDH formats
# implemented under NDA with no chances of source code release
rm -rf lib/libhbci4java-sizrdh*

%build
# TODO: solve this better
cp -r %{_prefix}/lib/jameica/src .
cp -r %{_prefix}/lib/jameica/lib .

export CLASSPATH="$(build-classpath xml-commons-apis)"
ant -f build/build.xml init compile jar zip src

%install
mkdir -p %{buildroot}%{_prefix}/lib/jameica/plugins
cp -r releases/%{version}-%{_build}/%{name} %{buildroot}%{_prefix}/lib/jameica/plugins

# unbundle SWT Chart
rm %{buildroot}%{_prefix}/lib/jameica/plugins/%{name}/lib/swtchart/org.swtchart_0.10.0.v20160212.jar
ln -sf %{_javadir}/org.swtchart.jar %{buildroot}%{_prefix}/lib/jameica/plugins/%{name}/lib/swtchart/org.swtchart_0.10.0.v20160212.jar

# unbundle libtowitoko
rm %{buildroot}%{_prefix}/lib/jameica/plugins/%{name}/lib/libtowitoko*
%ifarch x86_64
ln -sf  %{_libdir}/libtowitoko.so %{buildroot}%{_prefix}/lib/jameica/plugins/%{name}/lib/libtowitoko-2.0.7-amd64.so
%else
ln -sf  %{_libdir}/libtowitoko.so %{buildroot}%{_prefix}/lib/jameica/plugins/%{name}/lib/libtowitoko-2.0.7.so
%endif

# unbundle OBanToo
rm %{buildroot}%{_prefix}/lib/jameica/plugins/%{name}/lib/obantoo-bin-2.1.12.jar
ln -sf  %{_javadir}/obantoo-bin-2.1.12.jar %{buildroot}%{_prefix}/lib/jameica/plugins/%{name}/lib/obantoo-bin-2.1.12.jar

# icons
mkdir -p %{buildroot}%{_datadir}/icons/hicolor/16x16/apps/
mv %{buildroot}%{_prefix}/lib/jameica/plugins/%{name}/icons/%{name}-icon-16x16.png %{buildroot}%{_datadir}/icons/hicolor/16x16/apps/%{name}.png
mkdir -p %{buildroot}%{_datadir}/icons/hicolor/32x32/apps/
mv %{buildroot}%{_prefix}/lib/jameica/plugins/%{name}/icons/%{name}-icon-32x32.png %{buildroot}%{_datadir}/icons/hicolor/32x32/apps/%{name}.png
mkdir -p %{buildroot}%{_datadir}/icons/hicolor/64x64/apps/
mv %{buildroot}%{_prefix}/lib/jameica/plugins/%{name}/icons/%{name}-icon-64x64.png %{buildroot}%{_datadir}/icons/hicolor/64x64/apps/%{name}.png
rm -rf %{buildroot}%{_prefix}/lib/jameica/plugins/%{name}/icons

install -D -m 0644 %{name}.desktop %{buildroot}%{_datadir}/applications/%{name}.desktop
install -D -m 0644 %{name}.appdata.xml %{buildroot}%{_datadir}/appdata/%{name}.appdata.xml

%fdupes %{buildroot}

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%files
%defattr(-,root,root)
%doc build/ChangeLog
%license LICENSE COPYING
%{_prefix}/lib/jameica/plugins/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%dir %{_datadir}/appdata/
%{_datadir}/appdata/%{name}.appdata.xml

%changelog
* Fri Dec  7 2018 Fridrich Strba <fstrba@suse.com>
- Build against xml-commons-apis instead of xerces-j2-xml-apis
* Fri Nov 30 2018 ecsos@opensuse.org
- Update to 2.8.6
  - NEW: 0715 Neue obantoo-Version mit aktualisierter BLZ-Datei
    gültig ab 03.12.2018 (enthaelt auch ein Fix, das dazu fuehrte,
    dass auch bei korrekten Pruefziffern angezeigt wurde, die
    Pruefziffer sei nicht kontrolliert worden)
  - NEW: 0714 Spalte „art“ in Tabelle „umsatz“ auf 500 Zeichen
    vergrößert - siehe https://homebanking-hilfe.de/forum/topic.php?p=140726
- Changes from 2.8.5
  - NEW: 0713 Neue HBCI4Java-Version mit korrigiertem Umsatzabruf
    per CAMT auf Konten mit Soll-Saldo, Zwischensummen waren u.U.
    falsch - https://github.com/hbci4j/hbci4java/commit/5bac6886d5ef8f0c08aec8cc5c5ff35d866ce221
  - NEW: 0712 Kopieren/Verschieben der Kontoauszugsdateien jetzt
    möglich
  - NEW: 0711 BUGZILLA 1863 - Daten des elektronischen Kontoauszuges
    bearbeitbar
  - NEW: 0710 Die rohen CAMT-Daten können jetzt per
    „umsatz.camt.path=<Pfad>“ in
    'de.willuhn.jameica.hbci.HBCI.properties' gespeichert werden
  - DEL: 0709 Zusätzliche Längenprüfung unter Berücksichtigung des
    „ß“ entfernt - in SEPA-Zeiten vermutlich nicht mehr nötig
  - DEL: 0708 Hinweis mit der Längenbeschränkung der
    Verwendungszweck-Zeilen beim manuellen Bearbeiten eines
    Umsatzes entfernt
  - NEW: 0707 Neue HBCI4Java-Version mit Trimmen von Leerzeichen bei
    Umsatzabruf per CAMT - https://github.com/hbci4j/hbci4java/commit/7bba2509cc97f66aa932d916ae6a229170121448
  - NEW: 0706 Wenn die Bank trotz CAMT die Verwendungszweck-Zeilen
    alle 27 Zeichen trennt, dann neu zusammensetzen - siehe
    https://homebanking-hilfe.de/forum/topic.php?p=140438#real140438
  - CHG: 0705 Parameter „search.ignore.whitespace“ nicht permanent
    neu laden, performance-kritisch beim Laden der Umsätze
  - NEW: 0704 CSV-Import - zuletzt ausgewähltes Profil automatisch
    als Vorauswahl für den nächsten Import speichern
  - BUG: 0703 Wenn EREF beim Umsatzabruf per MT940 nicht korrekt
    aus Verwendungszweck extrahiert wurde und mehr als 100 Zeichen
    lang ist, dann abschneiden
  - NEW: 0702 Limit für Maximallänge des Verwendungszwecks in
    Umsatzbuchungen auf volle 255 Zeichen erhöht, damit auch
    Nicht-SEPA-Umsätze reinpassen
  - NEW: 0701 Umsatz-Export im PDF-Format jetzt wahlweise gruppierbar
    nach Konto oder nach Kategorie
- Changes from 2.8.4
  - NEW: 0700 Beim Empfang neuer UPD gleich die BPD mit
    aktualisieren
  - NEW: 0699 Neue HBCI4Java-Version mit Server-Adressen für
    IsBank - https://github.com/hbci4j/hbci4java/commit/649179cd52cc57bc540ce224cc8ef6ebaf0a806e
  - NEW: 0698 Scrollbalken in Einstellungsdialog für elektr.
    Kontoauszug für kleine Displays anzeigen, Fenstergröße speichern
  - NEW: 0697 BUGZILLA 1495 - automatisches Entfernen nicht
    unterstüzter Zeichen beim Einfügen des Verwendungszweck per
    Zwischenablage
  - NEW: 0696 Neue HBCI4Java-Version mit aktualisierter
    Server-Adresse der Sparda-Bank Berlin -
    https://github.com/hbci4j/hbci4java/commit/c91f6ed2c5b6b5ddc8d29c4ec6cb66428af6f15e
  - NEW: 0695 Support für dedizierte EndToEnd-ID in Umsätzen
  - BUG: 0694 NPE beim Parsen von CAMT-Dateien -
    https://github.com/hbci4j/hbci4java/commit/b2b607ad8b72012978badab5f8cc39a8f8dfccaa
  - CHG: 0693 Nachtrag zu Bugzilla 1864 - Kontofilter in der Liste
    der Konten auf der Startseite ausblenden, dort ist der Platz
    dafuer zu knapp
  - NEW: 0692 BUGZILLA 1864 - Filterkriterien in der Liste der
    Konten (u.a. deaktivierte Konten ausblenden)
  - NEW: 0691 Suchbegriff „flicker“ in die Liste der TAN-Verfahren
    aufgenommen, für die chipTAN USB in Frage kommt
  - NEW: 0690 Sonderbehandlung fuer Fehlerfall
    https://homebanking-hilfe.de/forum/topic.php?p=139423#real139423
    (Fehler beim Update der H2-Datenbank durch fehlerhaften H2-Treiber)
  - NEW: 0689 BUGZILLA 1861 - Unterstützung für benutzerspezifische
    CSV-Import-Profile
  - NEW: 0688 Neue obantoo-Version mit aktualisierter BLZ-Datei
    gültig ab 03.09.2018
  - NEW: 0687 Nur jene Synchronizisierungsoptionen anzeigen,
    die das Backend unterstützt
  - NEW: 0686 Manueller Import von Umsätzen im CAMT-Format
  - BUG: 0685 BUGZILLA 1860 - Kein Scrollbalken bei Anzeige einer
    überlangen Banknachricht
  - NEW: 0684 BUGZILLA 1621 - Support für Umsatz-Abruf im
    CAMT-Format
  - BUG: 0683 Neuer PIN/TAN-Bankzugang liess sich nicht mehr
    anlegen, da die ChipTAN-USB-Checkbox zu dem Zeitpunkt nicht
    korrekt berücksichtigt wurde
  - NEW: 0682 Neue HBCI4Java-Version mit CAMT-Bugfix -
    https://github.com/hbci4j/hbci4java/commit/3dc9ebf080810acc2636aef0c9413e0d40672dbb
  - NEW: 0681 Neue HBCI4Java-Version mit Unterstützung für
    CAMT - https://github.com/hbci4j/hbci4java/commit/ecca11320308b1fa1dc40bb37e6571d629064471
  - BUG: 0680 BUGZILLA 1858 - Hibiscus sucht auch bei deaktivierter
    chipTAN-USB-Option weiter nach Kartenlesern
  - NEW: 0679 Support für HKKAZ/HKKAN in Segment-Version 7 -
    https://github.com/hbci4j/hbci4java/commit/e3372a339bd5b9f0c2cea80155199f475dd46ed4
  - DEL: 0678 Option „Dauerhafte Internetverbindung, Aufforderung
    zum Verbinden nicht erforderlich“ aus den Einstellungen entfernt,
    braucht keiner mehr
  - NEW: 0677 Option „Alle Daten des Verwendungszwecks anzeigen“
    auch in Liste der Umsätze konfigurierbar (per Config-Button
    oben rechts)
  - NEW: 0676 In der Auswertung „Umsätze nach Kategorien → Im Verlauf“
    können durch Rechtsklick in die Grafik auch andere Intervalle
    (Jahr, Monat, Woche) ausgewählt werden.
  - BUG: 0675 In Kontoliste in der Spalte „verfügbarer Saldo“ das
    Währungskennzeichen des konkreten Kontos verwenden und nicht
    des ersten gefundenen
  - NEW: 0674 Wenn eine Bank im Verwendungszweck zwar das
    „SVWZ“-Tag liefert, es aber keinen Wert enthält, wird ebenfalls
    ein Fallback auf die Anzeige des kompletten Verwendungszweck
    gemacht
  - NEW: 0673 Beim MT940-Export in Feld :25: das Währungskennzeichen
    weglassen und die Auszugsnummer in Feld „:28C:“ mit dem
    Pseudowert „1“ ausgeben - SAP benötigt das für den Import
  - NEW: 0672 Fehler beim Ermitteln der Kartenleser-Features
    tolerieren (der tanJACK USB scheint das nicht zu unterstützen)
  - https://github.com/hbci4j/hbci4java/commit/22b702505bc9aef54bdb7b6663c948ce4b0b91cf
  - BUG: 0671 Export-Optionen „Saldo ausblenden“ und „Summenzeile
    anzeigen“ funktionierten nur, wenn die Checkboxen beim Export
    betätigt wurden
  - https://homebanking-hilfe.de/forum/topic.php?p=138415
* Tue Jul 17 2018 ecsos@opensuse.org
- update to 2.8.3
  - NEW: 0670 chipTAN USB auch dann anbieten, wenn zwar chipTAN
    optisch ausgewählt aber ein Kartenleser gefunden wurde
  - NEW: 0669 Support für chipTAN USB per ReinerSCT tanJACK USB
    https://github.com/hbci4j/hbci4java/commit/3d166d85aec80a1e8da0439fccde4e8c437c3ff2
  - NEW: 0668 Neuer Parameter „database.driver.h2.parameters“ in
    'de.willuhn.jameica.hbci.rmi.HBCIDBService.properties' zum
    Hinzufügen eigener JDBC-Parameter
  - CHG: 0667 0x6D im SW1 von Finalize-TX tolerieren, manche
    Kartenleser unterstützen das wohl nicht
    https://github.com/hbci4j/hbci4java/commit/8bfed0a12af312a88ba8270f5e67810545c4866f
  - CHG: 0666 Typo im Dialog zum Ausführen einer Überweisung
  - CHG: 0665 Beim Löschen der BPD explizit auch die
    UPD-Versionsnummer löschen sowie die BPD/UPD-Caches als expired
    markieren um auch ein Update des UPD-Caches zu forcieren
  - CHG: 0664 Auto-Korrektur des Dateinamens, wenn die Card-ID
    ungueltige Zeichen enthält, die nicht als Dateiname abbildbar
    wären https://github.com/hbci4j/hbci4java/commit/00ff4491a63edff7179dea3ed4a978993b64f5b2
  - NEW: 0663 Beim Abgleich der Konten die Kundenkennung mit berücksichtigen
* Sun Aug  6 2017 mailaender@opensuse.org
- update to version 2.6.20
- bundle hbci4java again (switched to maven)
- unbundle obantoo
* Sun Dec 25 2016 mailaender@opensuse.org
- update to version 2.6.19
- drop appdata.patch (included upstream)
* Sat Nov 19 2016 mailaender@opensuse.org
- update to version 2.6.18
- add appdata.patch
* Sat Jul  9 2016 mailaender@opensuse.org
- update to version 2.6.17
- avoid the volatile current version ZIP by using GitHub tags
* Wed Apr 20 2016 mailaender@opensuse.org
- update to version 2.6.15
* Tue Dec 29 2015 mailaender@opensuse.org
- removed binary only libct and libhbci4java-sizrdh
- made the package noarch
* Mon Dec 28 2015 mailaender@opensuse.org
- update to version 2.6.14
- unbundle swtchart, hbci4java and libtowitoko
* Wed Dec 31 2014 mailaender@opensuse.org
- update to version 2.6.11
* Fri Oct  3 2014 mailaender@opensuse.org
- update to version 2.6.8
* Mon Jul  7 2014 mailaender@opensuse.org
- update to version 2.6.7
* Fri May 16 2014 mailaender@opensuse.org
- update to version 2.6.6
* Wed Jan  8 2014 mailaender@opensuse.org
- update to version 2.6.1
* Sat Nov 16 2013 mailaender@opensuse.org
- initial packaging of version 2.4.2
